==> am_mod_blg_0_3.tar.gz: am_mod_blg_0_3/components/blg/language/1/barnraiser_01/entry_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/blg_common.inc.php');


//HEADER
$lang['hdr_entry'] = 								"blog entry";


// SUBMIT BUTTONS
$lang['sub_preview'] =                        	  	"preview";
$lang['sub_insert'] =                            	"add your entry";
$lang['sub_update'] =                            	"update your entry";


//BODY TEXT
$lang['txt_title'] = 								"title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_body'] = 								"body";
$lang['txt_none'] = 								"none";
$lang['txt_image'] = 								"image";
$lang['txt_language'] = 							"language";
?>

==> am_mod_blg_0_5.tar.gz: am_mod_blg_0_5/components/blg/language/1/barnraiser_01/entry_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/blg_common.inc.php');


//HEADER
$lang['hdr_entry'] = 								"blog entry";


// SUBMIT BUTTONS
$lang['sub_preview'] =                        	  	"validate";
$lang['sub_insert'] =                            	"add your entry";
$lang['sub_update'] =                            	"update your entry";


//BODY TEXT
$lang['txt_title'] = 								"title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_body'] = 								"body";
$lang['txt_none'] = 								"none";
$lang['txt_image'] = 								"image";
$lang['txt_language'] = 							"language";

$lang['txt_title_intro'] = 							"describe your blog entry";
$lang['txt_title_create'] = 						"create your blog entry";
$lang['txt_title_save'] = 							"check and save your blog entry";

?>
